Documentation
¶
Index ¶
- func Command(m *tgbotapi.Message) string
- func CommandArguments(m *tgbotapi.Message) string
- func CommandWithAt(m *tgbotapi.Message) string
- func IsCaptionCommand(m *tgbotapi.Message) bool
- func IsCommand(m *tgbotapi.Message) bool
- func ParseSlice(s string) ([]string, error)
- type Data
- type Interval
- type Reload
- type Utils
- type WriteMessageData
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CommandArguments ¶ added in v0.4.1
CommandArguments returns arguments from either Text or Caption
func CommandWithAt ¶ added in v0.4.1
CommandWithAtreturns the command from either Text or Caption with @ mention
func IsCaptionCommand ¶ added in v0.4.1
IsCaptionCommand checks if caption starts with a bot_command entity
func IsCommand ¶ added in v0.4.1
IsCommand returns true if message starts with a "bot_command" entity in either Text or Caption
func ParseSlice ¶ added in v0.2.4
Types ¶
Click to show internal directories.
Click to hide internal directories.